==> dl.php?src=linea21_1_8.zip: linea21/languages/es/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "publicaciones";

/*	nommage des modules
 *  	*/
$lang['publication']['name']='publicacion';
$lang['publication']['name2']='publicación(es)';
$lang['publication']['confirm_add'] = "publicación añadida correctamente";
$lang['publication']['confirm_mod'] = "publicación actualizada correctamente";
$lang['publication']['confirm_sup'] ="publicación eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Añadir nueva '.$lang['publication']['name'];
$lang['publication']['mod']= 'Editar '.$lang['publication']['name'];
$lang['publication']['sup']= 'Eliminar '.$lang['publication']['name'];
$lang['publication']['det']= ucfirst($lang['publication']['name']) . ' detalles';
$lang['publication']['list']= 'Ver '.$lang['publication']['name'].'es';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Apartado siguiente ';
$lang['publication']['prev_part']='Apartado anterior ';
$lang['publication']['goto']='Ir ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Añadir valores a la nueva '.$lang['publication']['name'];
$lang['publication']['mod_title']='Editar valores de la '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Las publicaciones le permitirán aumentar sus conocimientos en materia de desarrollo sostenible, describiendo su estado, planteando cuestiones relacionadas y fomentando la participación';

/*	check integrité© des données
 *  	*/
$lang['publication']['no_title'] = 'El título es requerido';
$lang['publication']['no_resume'] = 'El cuerpo es requerido';
$lang['publication']['no_theme'] = 'El área es requerida';
$lang['publication']['no_scale'] = 'La escala requerida';
$lang['publication']['no_author'] = 'El autor es requerido';
$lang['publication']['author_not_valid'] = 'El autor introducido no es válido';
$lang['publication']['author_not_rights'] = 'El autor introducido no dispone de los permisos necesarios';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='título';
$lang['publication']['resume']='cuerpo';
$lang['publication']['theme']='área asociada';
$lang['publication']['scale']='escala asociada';
$lang['publication']['statut']='estado';
$lang['publication']['comment']='comentarios';

$lang['publication']['template']='plantilla';
$lang['publication']['photouri']='imagen(es) asociada(s)';
$lang['publication']['visu1']='imagen asociada nÂ°1';
$lang['publication']['visu2']='imagen asociada nÂ°2';
$lang['publication']['author']='autor';
$lang['publication']['published_on']='publicado a fecha ';
$lang['publication']['not_published']='no publicado';

$lang['publication']['generals']='Información general';
$lang['publication']['parts']='detalles de la publicación';
$lang['publication']['listing']='Publicaciones Linea21';
$lang['publication']['link_res']='Enlace a la publicación';
$lang['publication']['biblio_res']='fuentes bibliográficas';
$lang['publication']['multi_res']='fuentes multimedia';
$lang['publication']['summary']='summary'; // @todo translation



/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' publicaciones agregadas recientemente';
$lang['publication']['qb_titlemod']=' publicaciones modificadas recientemente';
$lang['publication']['qb_titlesup']=' publicaciones eliminadas recientemente';
$lang['publication']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/

$lang['publication']['nb_total']='publicación(es) en la base de datos.';
$lang['publication']['statut_filter']='Mostrar por estados';
$lang['publication']['part_number']='apartado ';
$lang['publication']['part_number2']='apartado ';
$lang['publication']['description']='descripción';
$lang['publication']['all']='Mostrar lista completa';
$lang['publication']['noresult']='No existen publicaciones con ese criterio ';
$lang['news']['template_1']='Texto + imagen a la izquierda';
$lang['news']['template_2']='Texto + imagen a la derecha';
$lang['news']['template_3']='Solo texto';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Añadir un nuevo apartado a esta publicación";
$lang['publication']['add_new_linkres']="Añadir un nuevo enlace a esta publicación";
$lang['publication']['add_new_multires']="Añadir una nueva fuente multimedia a esta publicación";
$lang['publication']['add_new_bibliores']="Añadir una nueva fuente bibliográfica a esta publicación";

$lang['publication']['no_link']="No hay enlace a esta publicación";
$lang['publication']['del_link']="Eliminar enlace";
$lang['publication']['mod_link']="Editar enlace";

$lang['publication']['no_multi']="No hay fuentes multimedia asociadas a esta publicación";
$lang['publication']['del_multi']="Eliminar fuente multimedia";
$lang['publication']['mod_multi']="Editar fuente multimedia";

$lang['publication']['no_biblio']="No hay fuentes bibliográficas asociadas a esta publicación";
$lang['publication']['del_biblio']="Eliminar fuentes bibliográficas";
$lang['publication']['mod_biblio']="Actualizar fuentes bibliográficas";

$lang['publication']['no_part']="No hay apartados en esta publicación";
$lang['publication']['del_part']="Eliminar apartado";
$lang['publication']['mod_part']="Actualizar apartado";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Para añadir una publicación, inserte la información requerida en el formulario.';
$lang['publication']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['publication']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['publication']['help_list1']='Para mas información haga click en el título de la publicación.';
$lang['publication']['help_list2']="Para eliminar una publicación, haga click en el icono 'eliminar publicación'.";
$lang['publication']['help_list3']="Para editar una publicación, haga click en el icono 'editar publicación'.";
$lang['publication']['help_list4']='Para visualizar las publicaciones segun su estado, mostrar por estados.';
$lang['publication']['help_list5']='Para añadir una publicación, haga click en "añadir nueva publicación".';


$lang['publication']['help_mod1']='Para añadir una publicación, inserte la información requerida en el formulario.';
$lang['publication']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['publication']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['publication']['help_det1']="Para editar una publicación, haga click en el icono 'editar publicación'.";
$lang['publication']['help_det2']="Para eliminar una publicación, haga click en el icono 'eliminar publicación'.";
$lang['publication']['help_det3']='Para visualizar apartados, enlaces y fuentes bibliográficas y multimedia, haga click en el icono correspondiente.';
$lang['publication']['help_det4']='Para añadir-editar-eliminar apartados, enlaces y fuentes bibliográficas y multimedia de las publicaciones, haga click en el icono correspondiente.';

$lang['publication']['help_sup1']="Para abortar la eliminación, haga click en 'cancelar'.";


?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "publicaciones";

/*	nommage des modules
 *  	*/
$lang['publication']['name']='publicacion';
$lang['publication']['name2']='publicación(es)';
$lang['publication']['confirm_add'] = "publicación añadida correctamente";
$lang['publication']['confirm_mod'] = "publicación actualizada correctamente";
$lang['publication']['confirm_sup'] ="publicación eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Añadir nueva '.$lang['publication']['name'];
$lang['publication']['mod']= 'Editar '.$lang['publication']['name'];
$lang['publication']['sup']= 'Eliminar '.$lang['publication']['name'];
$lang['publication']['det']= ucfirst($lang['publication']['name']) . ' detalles';
$lang['publication']['list']= 'Ver '.$lang['publication']['name'].'es';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Apartado siguiente ';
$lang['publication']['prev_part']='Apartado anterior ';
$lang['publication']['goto']='Ir ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Añadir valores a la nueva '.$lang['publication']['name'];
$lang['publication']['mod_title']='Editar valores de la '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Las publicaciones le permitirán aumentar sus conocimientos en materia de desarrollo sostenible, describiendo su estado, planteando cuestiones relacionadas y fomentando la participación';

/*	check integrité© des données
 *  	*/
$lang['publication']['no_title'] = 'El título es requerido';
$lang['publication']['no_resume'] = 'El cuerpo es requerido';
$lang['publication']['no_level'] = 'El nivel es requerido';
$lang['publication']['no_scale'] = 'La escala requerida';
$lang['publication']['no_author'] = 'El autor es requerido';
$lang['publication']['author_not_valid'] = 'El autor introducido no es válido';
$lang['publication']['author_not_rights'] = 'El autor introducido no dispone de los permisos necesarios';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='título';
$lang['publication']['resume']='cuerpo';
$lang['publication']['level']='nivel asociada';
$lang['publication']['scale']='escala asociada';
$lang['publication']['statut']='estado';
$lang['publication']['comment']='comentarios';

$lang['publication']['template']='plantilla';
$lang['publication']['photouri']='imagen(es) asociada(s)';
$lang['publication']['visu1']='imagen asociada nÂ°1';
$lang['publication']['visu2']='imagen asociada nÂ°2';
$lang['publication']['author']='autor';
$lang['publication']['published_on']='publicado a fecha ';
$lang['publication']['not_published']='no publicado';

$lang['publication']['generals']='Información general';
$lang['publication']['parts']='detalles de la publicación';
$lang['publication']['listing']='Publicaciones Linea21';
$lang['publication']['link_res']='Enlace a la publicación';
$lang['publication']['biblio_res']='fuentes bibliográficas';
$lang['publication']['multi_res']='fuentes multimedia';
$lang['publication']['summary']='summary'; // @todo translation



/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' publicaciones agregadas recientemente';
$lang['publication']['qb_titlemod']=' publicaciones modificadas recientemente';
$lang['publication']['qb_titlesup']=' publicaciones eliminadas recientemente';
$lang['publication']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/

$lang['publication']['nb_total']='publicación(es) en la base de datos.';
$lang['publication']['statut_filter']='Mostrar por estados';
$lang['publication']['part_number']='apartado ';
$lang['publication']['part_number2']='apartado ';
$lang['publication']['description']='descripción';
$lang['publication']['all']='Mostrar lista completa';
$lang['publication']['noresult']='No existen publicaciones con ese criterio ';
$lang['news']['template_1']='Texto + imagen a la izquierda';
$lang['news']['template_2']='Texto + imagen a la derecha';
$lang['news']['template_3']='Solo texto';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Añadir un nuevo apartado a esta publicación";
$lang['publication']['add_new_linkres']="Añadir un nuevo enlace a esta publicación";
$lang['publication']['add_new_multires']="Añadir una nueva fuente multimedia a esta publicación";
$lang['publication']['add_new_bibliores']="Añadir una nueva fuente bibliográfica a esta publicación";

$lang['publication']['no_link']="No hay enlace a esta publicación";
$lang['publication']['del_link']="Eliminar enlace";
$lang['publication']['mod_link']="Editar enlace";

$lang['publication']['no_multi']="No hay fuentes multimedia asociadas a esta publicación";
$lang['publication']['del_multi']="Eliminar fuente multimedia";
$lang['publication']['mod_multi']="Editar fuente multimedia";

$lang['publication']['no_biblio']="No hay fuentes bibliográficas asociadas a esta publicación";
$lang['publication']['del_biblio']="Eliminar fuentes bibliográficas";
$lang['publication']['mod_biblio']="Actualizar fuentes bibliográficas";

$lang['publication']['no_part']="No hay apartados en esta publicación";
$lang['publication']['del_part']="Eliminar apartado";
$lang['publication']['mod_part']="Actualizar apartado";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Para añadir una publicación, inserte la información requerida en el formulario.';
$lang['publication']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['publication']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['publication']['help_list1']='Para mas información haga click en el título de la publicación.';
$lang['publication']['help_list2']="Para eliminar una publicación, haga click en el icono 'eliminar publicación'.";
$lang['publication']['help_list3']="Para editar una publicación, haga click en el icono 'editar publicación'.";
$lang['publication']['help_list4']='Para visualizar las publicaciones segun su estado, mostrar por estados.';
$lang['publication']['help_list5']='Para añadir una publicación, haga click en "añadir nueva publicación".';


$lang['publication']['help_mod1']='Para añadir una publicación, inserte la información requerida en el formulario.';
$lang['publication']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['publication']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['publication']['help_det1']="Para editar una publicación, haga click en el icono 'editar publicación'.";
$lang['publication']['help_det2']="Para eliminar una publicación, haga click en el icono 'eliminar publicación'.";
$lang['publication']['help_det3']='Para visualizar apartados, enlaces y fuentes bibliográficas y multimedia, haga click en el icono correspondiente.';
$lang['publication']['help_det4']='Para añadir-editar-eliminar apartados, enlaces y fuentes bibliográficas y multimedia de las publicaciones, haga click en el icono correspondiente.';

$lang['publication']['help_sup1']="Para abortar la eliminación, haga click en 'cancelar'.";


?>
